pub struct LifecycleSpan { /* private fields */ }Expand description
Observes existing work without changing its result, cancellation or authority. There is deliberately no Drop completion: a lost process cannot claim an outcome.
Implementations
Sourceimpl LifecycleSpan
impl LifecycleSpan
pub fn start(phase: Phase, provenance: Option<ConfigurationProvenance>) -> Self
Sourcepub fn start_operation(
phase: Phase,
provenance: Option<ConfigurationProvenance>,
operation_id: Option<Uuid>,
) -> Self
pub fn start_operation( phase: Phase, provenance: Option<ConfigurationProvenance>, operation_id: Option<Uuid>, ) -> Self
Recovery joins only the existing Operation, never an invented request ID.
pub fn run<T, E>( phase: Phase, provenance: Option<ConfigurationProvenance>, category: FailureCategory, work: impl FnOnce() -> Result<T, E>, ) -> Result<T, E>
pub fn complete<T, E>(self, result: &Result<T, E>, category: FailureCategory)
pub fn finish(self, outcome: Outcome, category: Option<FailureCategory>)